==> ros-rolling-rmw-fastrtps-shared-cpp_7.1.1.orig.tar.gz: ros-rolling-rmw-fastrtps-shared-cpp-7.1.1/src/rmw_get_gid_for_client.cpp <==
// Copyright 2022 Open Source Robotics Foundation, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "rmw/error_handling.h"
#include "rmw/impl/cpp/macros.hpp"
#include "rmw/rmw.h"
#include "rmw/types.h"

#include "rmw_fastrtps_shared_cpp/custom_client_info.hpp"
#include "rmw_fastrtps_shared_cpp/guid_utils.hpp"
#include "rmw_fastrtps_shared_cpp/rmw_common.hpp"

namespace rmw_fastrtps_shared_cpp
{
rmw_ret_t
__rmw_get_gid_for_client(
  const char * identifier,
  const rmw_client_t * client,
  rmw_gid_t * gid)
{
  RMW_CHECK_ARGUMENT_FOR_NULL(client, RMW_RET_INVALID_ARGUMENT);
  RMW_CHECK_TYPE_IDENTIFIERS_MATCH(
    client,
    client->implementation_identifier,
    identifier,
    return RMW_RET_INCORRECT_RMW_IMPLEMENTATION);
  RMW_CHECK_ARGUMENT_FOR_NULL(gid, RMW_RET_INVALID_ARGUMENT);

  const auto * info = static_cast<const CustomClientInfo *>(client->data);
  copy_from_fastrtps_guid_to_byte_array(info->writer_guid_, gid->data);
  gid->implementation_identifier = identifier;
  return RMW_RET_OK;
}
}  // namespace rmw_fastrtps_shared_cpp

==> ros-rolling-rmw-fastrtps-shared-cpp_9.2.0.orig.tar.gz: ros-rolling-rmw-fastrtps-shared-cpp-9.2.0/src/rmw_get_gid_for_client.cpp <==
// Copyright 2022 Open Source Robotics Foundation, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "rmw/error_handling.h"
#include "rmw/impl/cpp/macros.hpp"
#include "rmw/rmw.h"
#include "rmw/types.h"

#include "rmw_fastrtps_shared_cpp/custom_client_info.hpp"
#include "rmw_fastrtps_shared_cpp/guid_utils.hpp"
#include "rmw_fastrtps_shared_cpp/rmw_common.hpp"

namespace rmw_fastrtps_shared_cpp
{
rmw_ret_t
__rmw_get_gid_for_client(
  const char * identifier,
  const rmw_client_t * client,
  rmw_gid_t * gid)
{
  RMW_CHECK_ARGUMENT_FOR_NULL(client, RMW_RET_INVALID_ARGUMENT);
  RMW_CHECK_TYPE_IDENTIFIERS_MATCH(
    client,
    client->implementation_identifier,
    identifier,
    return RMW_RET_INCORRECT_RMW_IMPLEMENTATION);
  RMW_CHECK_ARGUMENT_FOR_NULL(gid, RMW_RET_INVALID_ARGUMENT);

  const auto * info = static_cast<const CustomClientInfo *>(client->data);
  // Use client's reader guid instead of writer guid for service event,
  // because service server uses client's reader guid for the event.
  // Service event message requires gid must be unique during transaction.
  copy_from_fastrtps_guid_to_byte_array(info->reader_guid_, gid->data);
  gid->implementation_identifier = identifier;
  return RMW_RET_OK;
}
}  // namespace rmw_fastrtps_shared_cpp
